==> jennifer_python-5.6.1.11-py2-none-any.whl: jennifer/pconstants/__init__.py <==

ACTIVE_SERVICE_RUNNING_MODE_NONE = 0
ACTIVE_SERVICE_RUNNING_MODE_SQL = 1
ACTIVE_SERVICE_RUNNING_MODE_EXTERNALCALL = 2

ACTIVE_SERVICE_STATUS_CODE_INITIALIZING = 10
ACTIVE_SERVICE_STATUS_CODE_RUN = 20
ACTIVE_SERVICE_STATUS_CODE_REJECTING = 21
ACTIVE_SERVICE_STATUS_CODE_REJECTED = 22
ACTIVE_SERVICE_STATUS_CODE_REPETITIVE_CALL_REJECTED = 23
ACTIVE_SERVICE_STATUS_CODE_DB_CONNECTING = 50
ACTIVE_SERVICE_STATUS_CODE_DB_CONNECTED = 51
ACTIVE_SERVICE_STATUS_CODE_DB_STMT_OPEN = 52
ACTIVE_SERVICE_STATUS_CODE_SQL_EXECUTING = 54
ACTIVE_SERVICE_STATUS_CODE_SQL_EXECUTED = 55
ACTIVE_SERVICE_STATUS_CODE_SQL_RS_OPEN = 56
ACTIVE_SERVICE_STATUS_CODE_DB_CLOSED = 60
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_EXECUTING = 70
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_EXECUTED = 71
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_END = 72

ERROR_TYPE_SERVICE_EXCEPTION = 1001
ERROR_TYPE_METHOD_EXCEPTION = 1012  # error.py
ERROR_TYPE_EXTERNAL_CALL_EXCEPTION = 1014
ERROR_TYPE_DB_CONNECTION_FAIL = 1015
ERROR_TYPE_DB_SQL_EXCEPTION = 1020
ERROR_TYPE_404 = 1022

REMOTE_CALL_TYPE_NONE = 0
REMOTE_CALL_TYPE_CUSTOM = 11
REMOTE_CALL_TYPE_HTTP = 12
REMOTE_CALL_TYPE_MONGODB = 17
REMOTE_CALL_TYPE_HTTPS = 18
REMOTE_CALL_TYPE_UNKNOWN_SQL_DATABASE = 21
REMOTE_CALL_TYPE_ORACLE = 22
REMOTE_CALL_TYPE_DB2 = 23
REMOTE_CALL_TYPE_MYSQL = 24
REMOTE_CALL_TYPE_POSTGRESQL = 25
REMOTE_CALL_TYPE_CUBRID = 26
REMOTE_CALL_TYPE_MSSQL = 27
REMOTE_CALL_TYPE_SOAP = 32
REMOTE_CALL_TYPE_SQLITE = 21  # REMOTE_CALL_TYPE_UNKNOWN_SQL_DATABASE

DB_MESSAGE_TYPE_UNKNOWN = 0
DB_MESSAGE_TYPE_OPEN = 1
DB_MESSAGE_TYPE_CLOSE = 2
DB_MESSAGE_TYPE_COMMIT = 3
DB_MESSAGE_TYPE_ROLLBACK = 4
DB_MESSAGE_TYPE_AUTO_COMMIT_FAILED = 5

SQL_DEF_PSTMT_EXE_QRY = 5

==> jennifer_python-5.6.1.18-py2-none-any.whl: jennifer/pconstants/__init__.py <==

ACTIVE_SERVICE_RUNNING_MODE_NONE = 0
ACTIVE_SERVICE_RUNNING_MODE_SQL = 1
ACTIVE_SERVICE_RUNNING_MODE_EXTERNALCALL = 2

ACTIVE_SERVICE_STATUS_CODE_INITIALIZING = 10
ACTIVE_SERVICE_STATUS_CODE_RUN = 20
ACTIVE_SERVICE_STATUS_CODE_REJECTING = 21
ACTIVE_SERVICE_STATUS_CODE_REJECTED = 22
ACTIVE_SERVICE_STATUS_CODE_REPETITIVE_CALL_REJECTED = 23
ACTIVE_SERVICE_STATUS_CODE_DB_CONNECTING = 50
ACTIVE_SERVICE_STATUS_CODE_DB_CONNECTED = 51
ACTIVE_SERVICE_STATUS_CODE_DB_STMT_OPEN = 52
ACTIVE_SERVICE_STATUS_CODE_SQL_EXECUTING = 54
ACTIVE_SERVICE_STATUS_CODE_SQL_EXECUTED = 55
ACTIVE_SERVICE_STATUS_CODE_SQL_RS_OPEN = 56
ACTIVE_SERVICE_STATUS_CODE_DB_CLOSED = 60
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_EXECUTING = 70
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_EXECUTED = 71
ACTIVE_SERVICE_STATUS_CODE_EXTERNALCALL_END = 72

ERROR_TYPE_SERVICE_EXCEPTION = 1001
ERROR_TYPE_METHOD_EXCEPTION = 1012  # error.py
ERROR_TYPE_EXTERNAL_CALL_EXCEPTION = 1014
ERROR_TYPE_DB_CONNECTION_FAIL = 1015
ERROR_TYPE_DB_SQL_EXCEPTION = 1020
ERROR_TYPE_404 = 1022

REMOTE_CALL_TYPE_NONE = 0
REMOTE_CALL_TYPE_CUSTOM = 11
REMOTE_CALL_TYPE_HTTP = 12
REMOTE_CALL_TYPE_MONGODB = 17
REMOTE_CALL_TYPE_HTTPS = 18
REMOTE_CALL_TYPE_UNKNOWN_SQL_DATABASE = 21
REMOTE_CALL_TYPE_ORACLE = 22
REMOTE_CALL_TYPE_DB2 = 23
REMOTE_CALL_TYPE_MYSQL = 24
REMOTE_CALL_TYPE_POSTGRESQL = 25
REMOTE_CALL_TYPE_CUBRID = 26
REMOTE_CALL_TYPE_MSSQL = 27
REMOTE_CALL_TYPE_SOAP = 32
REMOTE_CALL_TYPE_SQLITE = 40

DB_MESSAGE_TYPE_UNKNOWN = 0
DB_MESSAGE_TYPE_OPEN = 1
DB_MESSAGE_TYPE_CLOSE = 2
DB_MESSAGE_TYPE_COMMIT = 3
DB_MESSAGE_TYPE_ROLLBACK = 4
DB_MESSAGE_TYPE_AUTO_COMMIT_FAILED = 5

SQL_DEF_PSTMT_EXE_QRY = 5
